@@ -44,7 +44,7 @@ void open_all(void)
     if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,ATM_AAL5)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
     memset(&qos,0,sizeof(qos));
-    qos.txtp.class = qos.rxtp.class = ATM_ANYCLASS;
+    qos.txtp.traffic_class = qos.rxtp.traffic_class = ATM_ANYCLASS;
 	/* compatible with everything else */
     if (setsockopt(incoming,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
