@@ -204,6 +204,7 @@ static void send_arp(int fd,unsigned short op,unsigned long local_ip,
     put_addr(&here,remote_addr,&hdr->ar_thtl,&hdr->ar_tstl);
     put_ip(&here,remote_ip,&hdr->ar_tpln);
     send_packet(fd,buffer,here-buffer);
+    free(buffer);
 }
 
 
@@ -467,7 +468,7 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
     *entry->addr = *addr;
     /* need to revise this policy if we get user-settable QOS @@@ */
     memset(&entry->qos,0,sizeof(entry->qos));
-    entry->qos.txtp.class = ATM_UBR;
+    entry->qos.txtp.traffic_class = ATM_UBR;
     entry->qos.txtp.max_sdu = RFC1483LLC_LEN+RFC1626_MTU;
     entry->qos.rxtp = entry->qos.txtp;
     for (walk = entry->vccs; walk; walk = walk->next)
@@ -688,8 +689,10 @@ static int ioctl_set_pvc(ITF *itf,unsigned long ip,
     if (lookup_ip(itf,ip)) return -EEXIST; 
     if ((fd = connect_vcc((struct sockaddr *) addr,qos,0)) < 0) return fd;
     if ((result = set_ip(fd,ip)) < 0) return result;
-    if (flags & ATF_NULL)
+    if (flags & ATF_NULL) {
 	if ((result = set_encap(fd,0)) < 0) return result;
+	flags |= ATF_PERM;
+    }
     entry = alloc_entry(0);
     entry->state = as_valid;
     entry->ip = ip;
