@@ -3,6 +3,7 @@
 /* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
  
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -25,6 +26,12 @@
 #define COMPONENT "ARPD"
 
 
+#ifdef MEM_DEBUG
+extern int mpr(void);
+extern int mcheck (void (*)(int));
+#endif
+
+
 ITF *itfs = NULL;
 ENTRY *unknown_incoming = NULL;
 int debug;
@@ -43,6 +50,10 @@ int main(int argc,char **argv)
     const char *dump_dir;
     int c,background;
 
+#ifdef MEM_DEBUG
+    if (getenv("MCHECK")) mcheck(0);
+    if (mpr() < 0) return 1;
+#endif
     set_application("atmarpd");
     set_verbosity(NULL,DIAG_INFO);
     dump_dir = DUMP_DIR;
