@@ -52,7 +52,7 @@ void open_all(void)
     if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,ATM_AAL5)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
     memset(&qos,0,sizeof(qos));
-    qos.rxtp.class = qos.txtp.class = ATM_ANYCLASS;
+    qos.rxtp.traffic_class = qos.txtp.traffic_class = ATM_ANYCLASS;
     if (setsockopt(incoming,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
     memset(&addr,0,sizeof(addr));
@@ -167,7 +167,7 @@ static void recv_vcc(VCC *vcc)
     unsigned char buffer[MAX_BUFFER];
     int size;
 
-    size = read(vcc->fd,buffer,KERNEL_BUFFER_SIZE);
+    size = read(vcc->fd,buffer,MAX_BUFFER);
     if (!size) {
 	disconnect_vcc(vcc);
 	return;
