@@ -14,7 +14,7 @@ void open_all(void);
 void close_all(void);
 int do_close(int fd);
 void poll_loop(void);
-int connect_vcc(struct sockaddr *remote,int timeout);
+int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout);
 int set_ip(int fd,int ip);
 int set_encap(int fd,int mode);
 void send_packet(int fd,void *data,int length);
