@@ -41,8 +41,7 @@
 #define MAX_ILMI_MSG 484
 
 AsnOid *get_esi(int fd);
-void add_nsap(int itf, AsnOid *netprefix, AsnOid *esi);
-void delete_nsap(int itf);
+void update_nsap(int itf, AsnOid *netprefix, AsnOid *esi);
 int wait_for_message(int fd, struct timeval *timeout);
 int read_message(int fd, Message *message);
 int send_message(int fd, Message *message);
