@@ -55,7 +55,7 @@ static int print_table(void)
 static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s -a\n",name);
-    fprintf(stderr,"%6s %s -c [atmN]\n","",name);
+    fprintf(stderr,"%6s %s -c [[atm]N]\n","",name);
     fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [temp] [null]"
       "\n","",name);
     fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [temp] [arpsrv]\n",
@@ -112,7 +112,7 @@ int main(int argc,char **argv)
 		return 1;
 	    }
 	    if ((num = ioctl(s,op,req_num)) < 0) {
-		perror("ioctl");
+		perror("ioctl SIOCMKCLIP");
 		return 1;
 	    }
 	    if (req_num == -1) printf("atm%d\n",num);
@@ -149,7 +149,7 @@ int main(int argc,char **argv)
     req.arp_flags = ATF_PERM;
     if (op == SIOCSARP) {
 	memset(&req.arp_qos,0,sizeof(req.arp_qos));
-	req.arp_qos.txtp.class = ATM_UBR;
+	req.arp_qos.txtp.traffic_class = ATM_UBR;
 	for (i = optind+2; i < argc; i++)
 		if (!strcmp(argv[i],"temp")) req.arp_flags &= ~ATF_PERM;
 		else if (!strcmp(argv[i],"null")) req.arp_flags |= ATF_NULL;
@@ -177,7 +177,7 @@ int main(int argc,char **argv)
 	return 1;
     }
     if (ioctl(s,op,&req) < 0) {
-	perror("ioctl");
+	perror("ioctl SIOCxARP");
 	return 1;
     }
     return 0;
