@@ -48,13 +48,13 @@ int main(int argc,char **argv)
     if (text2atm(argv[1],(struct sockaddr *) &addr,sizeof(addr),T2A_PVC) < 0)
 	usage(argv[0]);
     memset(&qos,0,sizeof(qos));
-    if (argc != 3) qos.txtp.class = ATM_UBR;
+    if (argc != 3) qos.txtp.traffic_class = ATM_UBR;
     else {
-	qos.txtp.class = ATM_CBR;
+	qos.txtp.traffic_class = ATM_CBR;
 	qos.txtp.min_pcr = atoi(argv[2]);
 	qos.txtp.max_sdu = RFC1626_MTU;
     }
-    qos.rxtp.class = ATM_UBR;
+    qos.rxtp.traffic_class = ATM_UBR;
     qos.rxtp.max_sdu = RFC1626_MTU;
     if (setsockopt(s,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
 	perror("setsockopt SO_ATMQOS");
