@@ -112,41 +112,6 @@
 *
 *   User Data:
 *
-*     Packet transmit, receive calls, and transmit done callbacks contain a 
-*     "user_data" parameter.  The Connection Manager passes this parameter
-*     through and does not look at or modify it.  The user_data is a means of 
-*     communication between the SAP components and the AAL5 driver component.
-*     The description of the contents of the user data is outside of the scope
-*     of this interface specification, but since it is particularly relevant to
-*     SAP designers, a summary shall be described here.
-*
-*     The user data contains four fields:
-*
-*       LE_HEADER_VALID_FLAG....This flag is set if this is a transmit packet
-*                               from a LAN Emulation entity.  It instructs the
-*                               AAL5 driver to place the provided LAN Emulation
-*                               header on the front of the packet before
-*                               transmitting it.
-*
-*       LE_HEADER...............This is the actual 16-bit LAN Emulation header
-*                               that is prepended to the packet if the 
-*                               LE_HEADER_VALID_FLAG flag is set.
-*
-*       INTERNAL_FLAG...........This flag is set if the transmitted packet is
-*                               internally generated.  Internally generated
-*                               packets (i.e. LE-ARPs, ILMI packets, etc.)
-*                               are formatted differently from Operating System
-*                               packets and must be treated differently by the
-*                               AAL5 driver.
-*
-*       SAP_DATA................This 14-bit field is used only by the SAP
-*                               entity that transmits the packet.  It may be
-*                               read by the SAP when the transmit-done callback
-*                               returns the packet.  The SAP should
-*                               use this field to determine how to deallocate
-*                               the packet.  Note that internally generated
-*                               packets must be reclaimed differently than OS
-*                               generated packets.
 *
 *   AAL Data:
 *
@@ -155,102 +120,6 @@
 *     receive packet.  Refer to the definition of AAL_DATA in the "atm.h"
 *     header file.
 *
-* Call Sequence Requirements:
-*
-*   Since this interface is a registration interface, cm_sap_register must
-*   be called prior to calling any other CM function.  All other CM functions
-*   must be passed a valid SAP handle (which is returned from cm_sap_register).
-*
-*   Additionally, data packets may not be sent or received on this interface
-*   before a VC is established for that traffic.
-*
-* Example Usage Scenario (PVC only):
-*
-*   Callbacks are shown in parentheses.
-*
-*   cm_sap_register.....Before using the SAP interface, registration
-*                       must be completed.  If this SAP is only going to use
-*                       PVCs, it may clear the "accept_incoming" flag thus
-*                       telling the Connection Manager that it does not wish
-*                       to be offered incoming SVC connections.
-*
-*   cm_sap_pvc_setup....Before data can be exchanged over this interface,
-*                       a virtual channel must be established.  In this
-*                       case, a Permanent Virtual Channel (PVC) is being
-*                       created.  The SAP client provides the VCI of
-*                       the PVC.  It is assumed that the VPI will be zero.
-*
-*                       Note that in a PVC setup, the SAP chooses the VCI
-*                       of the new PVC.  This differs from SVC setup where the
-*                       VCI/VPI is chosen by the network.
-*
-*   (sap_vc_notify).....Some time later, the CM uses this callback to notify
-*                       the SAP that the PVC has been successfully set up.
-*
-*   cm_sap_xmt_vc.......Transmits a packet via the specified connection.  The
-*                       connection handle used is the same one returned by
-*                       the PVC setup call.  It is assumed that the rest of
-*                       the network (including the destination node) has been
-*                       setup to support this PVC.  If this is not the case,
-*                       the packet will not reach its destination.
-*
-*   (sap_rcv_callback)..A packet has been received on a VC bound to this
-*                       SAP (The VC became bound to this SAP during the
-*                       PVC setup).  This callback passes the packet to
-*                       the SAP along with its connection context.
-*
-*   cm_sap_pvc_teardown.When the SAP no longer needs the PVC, it uses
-*                       this call to remove the PVC and unbind it from
-*                       this SAP.
-*
-*   cm_sap_unregister...Cancel the registration with the CM.  After this
-*                       call completes, the SAP no longer exists from the
-*                       CM's perspective.
-*
-* Example Usage Scenario (with SVCs):
-*
-*   cm_sap_register.....Before using the SAP interface, registration must be
-*                       completed.  If this SAP client wishes to be offered
-*                       incoming SVC connections, it must set the
-*                       "accept_incoming" flag.
-*
-*   cm_sap_svc_setup....Request the setup of an SVC.  The caller provides the
-*                       ATM address of the desired destination and all of the
-*                       necessary parameters for the connection.
-*
-*   (sap_vc_notify).....Some time later, the CM uses this callback to notify
-*                       the SAP of the status of its SVC request.
-*
-*   cm_sap_xmt_atm......Once an SVC is set up for an ATM address, packets may
-*                       be sent to that ATM address.  The CM will look up the
-*                       ATM address in the mapping module to determine the
-*                       correct VC for transmission.  If the ATM address is
-*                       not associated with a valid VC, an error will be
-*                       returned.
-*
-*   cm_sap_xmt_vc.......Another way to transmit data is directly to the VC.
-*                       This is a faster way to transmit.  Generally this will
-*                       be used by the LAN Emulation Client since it will
-*                       already have the connection handle from its MAC
-*                       address lookup.
-*
-*   (sap_rcv)...........A packet has been received on a VC bound to this SAP.
-*                       The binding happens during SVC setup.
-*
-*   (sap_connect).......This callback is invoked when an incoming SVC request
-*                       is received.  The SAP now has the option to accept or
-*                       reject the call.
-*
-*                       When the CM receives an incoming connection request, it
-*                       offers this connection (via the sap_connect call
-*                       to each SAP in some arbitrary order.  The first SAP to
-*                       accept the connection gets the connection.  If none of
-*                       the matching SAPs accepts the connection, the CM
-*                       rejects the connection.
-*
-*   cm_sap_unregister...Cancel the registration.  This will automatically
-*                       close all SVCs and PVCs bound to this SAP.
-*
 */
 #ifndef CM_SAP_H
 #define CM_SAP_H
@@ -631,7 +500,6 @@ STATUS cm_sap_svc_setup (HANDLE     sap_handle,
 *
 * Arguments:
 *   conn_handle     - (IN)  Connection handle of the SVC to be removed.
-*   p_release_info  - (IN)  Reason for this release.
 *              
 * Returns:
 *   STATUS_K_PENDING        - Success: Async operation has begun
@@ -642,8 +510,7 @@ STATUS cm_sap_svc_setup (HANDLE     sap_handle,
 * Postconditions:
 *   None
 --*/
-STATUS cm_sap_svc_teardown (HANDLE        conn_handle,
-                            RELEASE_INFO *p_release_info);
+STATUS cm_sap_svc_teardown (HANDLE        conn_handle);
 
 /*++
 * =================
