@@ -887,8 +887,8 @@ conn_create_listensocket(HANDLE sap_handle, HANDLE conn_context,
  
   memset(conn_info , 0, sizeof(CONN_INFO));
 
-  conn_info->conqos.txtp.class = ATM_UBR;
-  conn_info->conqos.rxtp.class = ATM_UBR;
+  conn_info->conqos.txtp.traffic_class = ATM_UBR;
+  conn_info->conqos.rxtp.traffic_class = ATM_UBR;
   conn_info->conqos.txtp.max_pcr = max_cell_rate;  
   conn_info->conqos.rxtp.max_pcr = max_cell_rate;
 
