@@ -15,11 +15,12 @@
 
 void conn_call_callbacks(void);
 void conn_get_fds(fd_set *fds);
+void conn_get_connecting_fds(fd_set *fds);
 int conn_check_incoming(fd_set *fds);
 int conn_create_listensocket(HANDLE sap_context, HANDLE conn_context,
 			     unsigned short blli_codepoint,
-			     int max_cell_rate, HANDLE *p_conn_handle);
-int get_ouratmaddr(int s, struct sockaddr_atmsvc *addr);
+			     int max_cell_rate,
+			     HANDLE *p_conn_handle);
 int conn_set_kernel_socket(int fd);
 /*
 void conn_convert_to_data_vcc(HANDLE conn_handle);
@@ -28,6 +29,10 @@ void conn_convert_to_data_vcc(HANDLE conn_handle);
 /*
  *
  * $Log: conn.h,v $
+ * Revision 1.2  1996/08/06 14:14:11  carnil
+ * Cleaning up
+ * Address handling moved to address.c from conn.c
+ *
  * Revision 1.1  1996/05/23 11:50:54  carnil
  * Initial revision
  *
