@@ -24,7 +24,7 @@
 /*
  * Kernel interface
  *
- * $Id: kernel_itf.c,v 1.7 1996/05/29 08:22:39 carnil Exp carnil $
+ * $Id: kernel_itf.c,v 1.9 1996/07/07 11:51:47 carnil Exp carnil $
  *
  */
 /* System includes */
@@ -47,7 +47,7 @@
 
 #define EMOD MOD_UP_DRV
 #define EINST "kernel_itf.c"
-#define EMASK (EM_NERR | EM_SERR | EM_ASSERT)
+#include "emask.h"
 
 /* Local vars */
 extern int errno;
@@ -135,7 +135,6 @@ kernel_sendmsg(atmlec_msg_type type, unsigned char *mac_addr,
 int 
 kernel_register_callback(atmlec_msg_type type, kernel_callback callback)
 {
-  int i;
   if (callback_funcs[type])
     return -1;
   callback_funcs[type] = callback;
@@ -143,7 +142,7 @@ kernel_register_callback(atmlec_msg_type type, kernel_callback callback)
   return 0;
 }
 
-static char*
+static const char*
 get_mesg_type_str(atmlec_msg_type type)
 {
   switch(type) {
@@ -180,7 +179,6 @@ void
 kernel_dispatch_handlers(void)
 {
   struct atmlec_msg mesg;
-  int i;
 
   EVENT(EM_DEBUG,("Received message from kernel\n"));
   if (read(lec_socket, &mesg, sizeof(mesg))<0) {
@@ -197,6 +195,12 @@ kernel_dispatch_handlers(void)
 /*
  *
  * $Log: kernel_itf.c,v $
+ * Revision 1.9  1996/07/07 11:51:47  carnil
+ * Global msg_mask
+ *
+ * Revision 1.8  1996/06/10 04:27:28  carnil
+ * compiler warning fix
+ *
  * Revision 1.7  1996/05/29 08:22:39  carnil
  * *** empty log message ***
  *
