@@ -24,7 +24,7 @@
 /*
  * Lec arp cache daemon part
  *
- * $Id: lec_arp.c,v 1.12 1996/07/07 11:51:47 carnil Exp carnil $
+ * $Id: lec_arp.c,v 1.13 1996/08/06 14:14:11 carnil Exp carnil $
  *
  */
 
@@ -45,10 +45,7 @@
 
 #include "af_lane.h"
 #include "cm.h"
-#include "map.h"
 #include "svc_info.h"
-#include "map_data.h"
-#include "lec_mgt.h"
 #include "lec.h"
 #include "lec_arp.h"
 
@@ -100,14 +97,14 @@ kernel_flush_xmt_callback(struct atmlec_msg *mesg)
 {
   LA_ELAN_CONTEXT *p_elan;
   ADDR_ATM *to_pass;
-  MAP_ESI_RECORD dumb;
+  UINT32 dumb;
 
   to_pass = (ADDR_ATM*)mesg->content.normal.atm_addr;
 
   utl_list_traverse(lec_arp_context.elan_list, p_elan) {
     lec_arp_context.flush_xmt_callback(p_elan->lc_elan_handle, *to_pass,&dumb);
     kernel_sendmsg(l_flush_tran_id, mesg->content.normal.mac_addr,NULL,
-		   NULL, dumb.flush_tran_id);
+		   NULL, dumb);
   }
 }
 
@@ -201,18 +198,11 @@ la_deregister(HANDLE la_elan_handle)
   p_elan    = (LA_ELAN_CONTEXT *) la_elan_handle;
   p_context = (LA_CONTEXT      *) p_elan->la_handle;
   
-
   utl_list_delete(p_context->elan_list, p_elan);
   
   mem_free(EINST,p_elan);
 }
 
-void 
-la_event_mask_set(HANDLE la_elan_handle,
-		  UINT32 event_mask)
-{
-}
-
 void 
 la_config(HANDLE la_elan_handle, LAN_TYPE lan_type,
 	  BOOLEAN proxy_flag, UINT16 max_unknown_frame_count,
@@ -238,12 +228,6 @@ la_config(HANDLE la_elan_handle, LAN_TYPE lan_type,
   kernel_sendmsg(l_config, NULL, NULL, &conf_mesg, 0);
 }
 
-void 
-la_elan_reset(HANDLE la_elan_handle)
-{
-  kernel_sendmsg(l_reset, NULL, NULL, NULL, 0);
-}
-
 STATUS 
 la_perm_add(HANDLE la_elan_handle, ESI esi, ADDR_ATM addr_atm)
 {
@@ -268,6 +252,8 @@ la_arp_update(HANDLE    la_elan_handle,
 	      ADDR_ATM  addr_atm,
 	      BOOLEAN   remote_flag)
 {
+  EVENT(EM_DEBUG,("ARP update for %2.2x%2.2x%2.2x%2.2x%2.2x%2.2x\n",
+		  esi[0],esi[1],esi[2],esi[3],esi[4],esi[5]));
   kernel_sendmsg(l_arp_update, (unsigned char *)esi,
 		 (unsigned char *)&addr_atm, NULL, remote_flag==TRUE?1:0);
 }
@@ -293,6 +279,9 @@ la_topology_change_set(HANDLE  la_elan_handle,
 /*
  *
  * $Log: lec_arp.c,v $
+ * Revision 1.13  1996/08/06 14:14:11  carnil
+ * Cleaning up
+ *
  * Revision 1.12  1996/07/07 11:51:47  carnil
  * Global msg_mask
  * Arp cache deletion by atm_address
