@@ -26,7 +26,7 @@
  * Utility functions which are used, but not defined in DIGITAL's 
  * code are defined here.
  *
- * $Id: utils.c,v 1.6 1996/07/07 11:51:47 carnil Exp carnil $
+ * $Id: utils.c,v 1.7 1996/08/06 14:14:11 carnil Exp carnil $
  *
  */
 
@@ -37,7 +37,6 @@
 /* Digital includes */
 #include "utl.h"
 #include "utl_os.h"
-#include "line_up.h"
 #include "codes.h"
 #include "g_event.h"
 
@@ -55,41 +54,16 @@ typedef struct _MemList_t {
 
 static MemList_t *memlist = NULL;
 
-void 
-utl_mem_zero (void *p_buf, int size)
-{
-  memset(p_buf,0,size);
-}
-
-void 
-utl_mem_copy (void *p_from, void *p_to, int size)
-{
-  memcpy(p_to, p_from, size);
-}
-
-void
-os_buff_hdr_copy (void *p_pkt, UINT32 pkt_len, void *p_dst,
-		  UINT32  dst_len, UINT32 *p_bytes_copied)
-{
-  memcpy(p_dst, p_pkt, pkt_len>dst_len?dst_len:pkt_len);
-  *p_bytes_copied = pkt_len>dst_len?dst_len:pkt_len;
-}
-
 void*
 os_mem_alloc(UINT32 size)
 {
-  void *memory;
-
-  memory = malloc(size);
-  if (memory)
-    memset(memory,0,size);
-  return memory;
+  return(mem_alloc("utils.c",size));
 }
 
 void 
 os_mem_dealloc(void *p_mem)
 {
-  (void)free(p_mem);
+  mem_free("utils.c", p_mem);
 }
 
 void*
@@ -105,8 +79,8 @@ mem_alloc(const char *unit, unsigned long nbytes)
   tmp->unit[strlen(unit)] = '\0';
   tmp->next = memlist;
   memlist = tmp;
-  EVENT(EM_DEBUG,("Unit %s allocates %ld bytes of memory from 0x%lx\n",
-		  unit, nbytes, (unsigned long)tmp->mem));
+  EVENT(EM_MEM,("Unit %s allocates %ld bytes of memory from 0x%lx\n",
+		unit, nbytes, (unsigned long)tmp->mem));
   return tmp->mem;
 
 }
@@ -116,7 +90,7 @@ mem_free(const char *unit, const void *mem)
 {
   MemList_t *tmp, *prev = NULL;
  
-  EVENT(EM_DEBUG, ("Unit %s frees ptr 0x%lx\n", unit, (unsigned long)mem));
+  EVENT(EM_MEM, ("Unit %s frees ptr 0x%lx\n", unit, (unsigned long)mem));
 
   for (tmp = memlist; tmp != NULL; prev = tmp, tmp = tmp->next) {
     if (tmp->mem == mem) {
@@ -126,7 +100,7 @@ mem_free(const char *unit, const void *mem)
   /* Found a match? */
   if (tmp) {
     if (strcmp(tmp->unit, unit) != 0) {
-      EVENT(EM_DEBUG,
+      EVENT(EM_MEM,
 	    ("Unit %s frees ptr 0x%lx size %d allocated by unit %s\n",
 	     unit, (unsigned long)tmp->mem, tmp->memsize, 
 	     tmp->unit));
@@ -137,25 +111,34 @@ mem_free(const char *unit, const void *mem)
     if (prev != NULL) {
       prev->next = tmp->next;
     }
+    free(tmp->unit);
     free(tmp->mem);
     free(tmp);
   }
   else {
-    EVENT(EM_DEBUG, ("could not find block 0x%lx for freeing\n", 
-		     (unsigned long)mem));
+    EVENT(EM_MEM, ("could not find block 0x%lx for freeing\n", 
+		   (unsigned long)mem));
   }
 }
 
-STATUS 
-line_up_uni_version_get (HANDLE  line_up_handle, UINT8  *p_uni_version)
+void
+mem_usage(void)
 {
-  *p_uni_version  = UNI_3_1;
-  return STATUS_K_SUCCESS;
-}
+  MemList_t *tmp;
 
+  tmp = memlist;
+  
+  printf("Memory usage:\n");
+  for(tmp=memlist;tmp;tmp=tmp->next) {
+    printf("\t%20s\t:%p %6d bytes\n",tmp->unit, tmp->mem, tmp->memsize);
+  }
+}
 /*
  *
  * $Log: utils.c,v $
+ * Revision 1.7  1996/08/06 14:14:11  carnil
+ * Malloc changed to mem_alloc
+ *
  * Revision 1.6  1996/07/07 11:51:47  carnil
  * Global_msgmask
  *
