@@ -73,6 +73,10 @@ static int do_svc(char *buffer,int length,const struct sockaddr_atmsvc *addr,
     if (!*addr->sas_addr.pub && !*addr->sas_addr.prv) return FATAL;
     if (*addr->sas_addr.pub) {
 	len = strlen(addr->sas_addr.pub);
+	if (!*addr->sas_addr.prv && length >= len+2) {
+	    *buffer++ = '+';
+	    length--;
+	}
 	if (length < len+1) return FATAL;
 	strcpy(buffer,addr->sas_addr.pub);
 	buffer += len;
