@@ -8,6 +8,20 @@
 
 typedef enum { vt_id,vt_case,vt_multi,vt_length } VALUE_TYPE;
 
+typedef struct _name {
+    const char *value;
+    const char *name;
+    struct _name *next;
+} NAME;
+
+typedef struct _name_list {
+    /* --- the following fields are initialized by the parser */
+    const char *list_name;
+    NAME *list;
+    int id; /* initialized to -1 = unassigned */
+    struct _name_list *next;
+} NAME_LIST;
+
 typedef struct {
     /* --- the following fields are initialized by the parser */
     VALUE_TYPE type;
@@ -21,6 +35,7 @@ typedef struct {
 typedef struct _field {
     /* --- the following fields are initialized by the parser */
     const char *id;
+    NAME_LIST *name_list;
     int size;
     int var_len;
     int pos; /* modified in the first phase */
