@@ -9,8 +9,10 @@ static int q_dump = 0;
 int q_dump = 0;
 #endif
 
-
-#ifdef STANDALONE
+#ifndef STANDALONE
+#define DUMP qd_dump
+#else
+#define DUMP printf
 
 #include <stdarg.h>
 #include <stdio.h>
@@ -39,6 +41,15 @@ void q_report(int severity,const char *msg,...)
 #endif
 
 
+#define LENGTH_STACK 10
+
+
+typedef struct {
+    int pos,size;
+    unsigned char *start;
+} LEN_BUF;
+
+
 static int q_test(unsigned char *table,int pos)
 {
     return !!(table[pos >> 3] & (1 << (pos & 7)));
@@ -297,17 +308,6 @@ int q_read(Q_DSC *dsc,int field,void *buf,int size)
     return len;
 }
 
-#endif
-
-
-#define LENGTH_STACK 10
-
-
-typedef struct {
-    int pos,size;
-    unsigned char *start;
-} LEN_BUF;
-
 
 static int q_compose(Q_DSC *dsc,unsigned char *buf,int size)
 {
@@ -416,6 +416,8 @@ static int q_compose(Q_DSC *dsc,unsigned char *buf,int size)
     }
 }
 
+#endif
+
 
 static int _q_parse(Q_DSC *dsc,unsigned char *buf,int size)
 {
@@ -437,27 +439,27 @@ static int _q_parse(Q_DSC *dsc,unsigned char *buf,int size)
 		    unsigned long value;
 		    int len;
 
-		    for (i = dump_fields[*pc].level; i; i--) printf("  ");
-		    printf("%s =",dump_fields[*pc++].name);
+		    for (i = dump_fields[*pc].level; i; i--) DUMP("  ");
+		    DUMP("%s =",dump_fields[*pc++].name);
 		    len = *pc == OP_COPYVAR ? (end-pos)*8 : pc[3];
 		    if (len <= 32) {
 			const SYM_NAME *sym;
 
 			value = q_get(pos,pc[2] & 7,pc[3]);
 			if (!(sym = dump_fields[pc[-1]].sym))
-			    printf(" %ld (0x%lx)\n",value,value);
+			    DUMP(" %ld (0x%lx)\n",value,value);
 			else {
 			    while (sym->name)
 				if (sym->value == value) break;
 				else sym++;
-			    if (sym->name) printf(" %s\n",sym->name);
-			    else printf(" %ld (0x%lx)\n",value,value);
+			    if (sym->name) DUMP(" %s\n",sym->name);
+			    else DUMP(" %ld (0x%lx)\n",value,value);
 			}
 		    }
 		    else {
 			for (i = 0; i < len/8; i++)
-			    printf(" %02x",pos[pc[1]/8+i]);
-			putchar('\n');
+			    DUMP(" %02x",pos[pc[1]/8+i]);
+			DUMP("\n");
 		    }
 		}
 		break;
@@ -539,7 +541,7 @@ static int _q_parse(Q_DSC *dsc,unsigned char *buf,int size)
 			    break;
 			}
 		    if (!len) {
-			q_report(Q_ERROR,"case failed (pc %d)",pc-construct);
+			q_report(Q_ERROR,"case failed (pc %d)",pc-parse);
 			return -1;
 		    }
 		}
@@ -619,8 +621,10 @@ int PREFIX(close)(Q_DSC *dsc)
 {
     int size;
 
+#ifndef DUMP_MODE
     if (dsc->buffer && !dsc->error)
 	size = q_compose(dsc,dsc->buffer,dsc->buf_size);
+#endif
     free(dsc->data);
     free(dsc->required);
     free(dsc->field_present);
