@@ -69,8 +69,8 @@ static int send_setup(SOCKET *sock)
 	if (!error) error = -EADDRNOTAVAIL;
     }
     else {
-	q_assign(&dsc,QF_cgpn_plan,2);
-	q_assign(&dsc,QF_cgpn_type,0);
+	q_assign(&dsc,QF_cgpn_plan,ATM_NP_NSAP);
+	q_assign(&dsc,QF_cgpn_type,ATM_TON_UNKNOWN);
 	q_write(&dsc,QF_cgpn,(void *) local->sas_addr.prv,ATM_ESA_LEN);
     }
     if (net) {
@@ -266,8 +266,8 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 #endif
 		      );
 		    START_TIMER(sock,T308_1);
-		    new_state(sock,sock->state == ss_connected ? ss_rel_req :
-		      ss_wait_rel);
+		    new_state(sock,sock->state == ss_connecting ||
+		      sock->state == ss_connected ? ss_rel_req : ss_wait_rel);
 		    return;
 		case ss_rel_ind:
 		    send_release_complete(sock->call_ref,0); /* @@@ */
