@@ -490,10 +490,10 @@ static void process_q2931(void *msg)
     mid = q_fetch(&in_dsc,QF_msg_type);
     if (mid == QMSG_REST_ACK) return;
     if (mid == QMSG_RESTART) { /* 5.5.5.2 */
-	int class;
+	int rst_class;
 
-	class = q_fetch(&in_dsc,QF_rst_class);
-	switch (class) {
+	rst_class = q_fetch(&in_dsc,QF_rst_class);
+	switch (rst_class) {
 	    case ATM_RST_IND_VC:
 		{
 		    int vpi,vci;
