@@ -295,10 +295,10 @@ int no_check = 0;
 		exit(1);
 	    }
 	memset(&qos,0,sizeof(qos));
-	if (!trans) qos.rxtp.class = ATM_UBR;
-	else if (!pcr) qos.txtp.class = ATM_UBR;
+	if (!trans) qos.rxtp.traffic_class = ATM_UBR;
+	else if (!pcr) qos.txtp.traffic_class = ATM_UBR;
 	    else {
-		qos.txtp.class = ATM_CBR;
+		qos.txtp.traffic_class = ATM_CBR;
 		qos.txtp.max_pcr = pcr;
 	    }
 	qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
